@@ -1,10 +1,10 @@
 """Module containing different I/O functions to load and save sleep data."""
 from pathlib import Path
-from typing import Union, Dict
+from typing import Dict, Union
 
 import pandas as pd
-from biopsykit.utils._datatype_validation_helper import _assert_file_extension
 
+from biopsykit.utils._datatype_validation_helper import _assert_file_extension
 from biopsykit.utils._types import path_t
 from biopsykit.utils.datatype_helper import is_sleep_endpoint_dataframe, is_sleep_endpoint_dict
 
