@@ -18,6 +18,7 @@ MAP_STAT_TESTS = {
     "welch_anova": pg.welch_anova,
     "rm_anova": pg.rm_anova,
     "mixed_anova": pg.mixed_anova,
+    "ancova": pg.ancova,
     "kruskal": pg.kruskal,
     "pairwise_ttests": pg.pairwise_ttests,
     "pairwise_tukey": pg.pairwise_tukey,
@@ -31,6 +32,7 @@ MAP_STAT_PARAMS = {
     "welch_anova": ["dv", "between"],
     "rm_anova": ["dv", "within", "subject"],
     "mixed_anova": ["dv", "between", "within", "subject"],
+    "ancova": ["dv", "between", "covar"],
     "kruskal": ["dv", "between"],
     "pairwise_ttests": ["dv", "between", "within", "subject", "effsize", "tail", "parametric", "padjust"],
     "pairwise_tukey": ["dv", "between", "effsize"],
@@ -44,6 +46,7 @@ MAP_NAMES = {
     "welch_anova": "Welch ANOVA",
     "rm_anova": "Repeated-measurement ANOVA",
     "mixed_anova": "Mixed ANOVA",
+    "ancova": "ANCOVA",
     "kruskal": "Kruskal-Wallis H-test for independent samples",
     "pairwise_ttests": "Pairwise t-Tests",
     "pairwise_tukey": "Pairwise Tukey's HSD (Honestly Significant Differences) Test",
@@ -925,11 +928,13 @@ class StatsPipeline:
             box_pairs.index = index
         return box_pairs
 
-    @staticmethod
-    def _get_box_pairs_multi(stats_data: pd.DataFrame, x: str):
+    def _get_box_pairs_multi(self, stats_data: pd.DataFrame, x: str):
         if x is None:
             raise ValueError("'x' must be specified when 'plot_type' is 'multi'!")
-        stats_data = stats_data.set_index(x)
+        if x in stats_data.columns:
+            stats_data = stats_data.set_index(x)
+        else:
+            stats_data = stats_data.set_index(self.params["groupby"])
         return stats_data.apply(lambda row: ((row.name, row["A"]), (row.name, row["B"])), axis=1)
 
     def _display_category(  # pylint:disable=too-many-branches
